summaryrefslogtreecommitdiffstats
path: root/server
diff options
context:
space:
mode:
Diffstat (limited to 'server')
-rw-r--r--server/display-channel.c7
-rw-r--r--server/red_worker.c30
2 files changed, 19 insertions, 18 deletions
diff --git a/server/display-channel.c b/server/display-channel.c
index f443dd01..0be3e42a 100644
--- a/server/display-channel.c
+++ b/server/display-channel.c
@@ -708,9 +708,10 @@ static int current_add(DisplayChannel *display, Ring *ring, Drawable *drawable)
current_add_drawable(display, drawable, ring);
} else {
/*
- * red_detach_streams_behind can affect the current tree since it may
- * trigger calls to update_area. Thus, the drawable should be added to the tree
- * before calling red_detach_streams_behind
+ * red_detach_streams_behind can affect the current tree since
+ * it may trigger calls to display_channel_draw. Thus, the
+ * drawable should be added to the tree before calling
+ * red_detach_streams_behind
*/
current_add_drawable(display, drawable, ring);
if (is_primary_surface(display, drawable->surface_id)) {
diff --git a/server/red_worker.c b/server/red_worker.c
index 2a7b4158..d3a675b0 100644
--- a/server/red_worker.c
+++ b/server/red_worker.c
@@ -152,9 +152,9 @@ typedef struct BitmapData {
static inline int validate_surface(DisplayChannel *display, uint32_t surface_id);
-static void red_update_area(DisplayChannel *display, const SpiceRect *area, int surface_id);
-static void red_update_area_till(DisplayChannel *display, const SpiceRect *area, int surface_id,
- Drawable *last);
+static void display_channel_draw(DisplayChannel *display, const SpiceRect *area, int surface_id);
+static void display_channel_draw_till(DisplayChannel *display, const SpiceRect *area, int surface_id,
+ Drawable *last);
static inline void display_begin_send_message(RedChannelClient *rcc);
static void dcc_release_glz(DisplayChannelClient *dcc);
static void display_channel_client_release_item_before_push(DisplayChannelClient *dcc,
@@ -594,7 +594,7 @@ static void display_stream_trace_add_drawable(DisplayChannel *display, Drawable
static void surface_flush(DisplayChannel *display, int surface_id, SpiceRect *rect)
{
- red_update_area(display, rect, surface_id);
+ display_channel_draw(display, rect, surface_id);
}
static void red_flush_source_surfaces(DisplayChannel *display, Drawable *drawable)
@@ -855,9 +855,9 @@ static void dcc_detach_stream_gracefully(DisplayChannelClient *dcc,
stream_id, stream->current != NULL);
rect_debug(&upgrade_area);
if (update_area_limit) {
- red_update_area_till(DCC_TO_DC(dcc), &upgrade_area, 0, update_area_limit);
+ display_channel_draw_till(DCC_TO_DC(dcc), &upgrade_area, 0, update_area_limit);
} else {
- red_update_area(DCC_TO_DC(dcc), &upgrade_area, 0);
+ display_channel_draw(DCC_TO_DC(dcc), &upgrade_area, 0);
}
dcc_add_surface_area_image(dcc, 0, &upgrade_area, NULL, FALSE);
}
@@ -962,7 +962,7 @@ static void red_get_area(DisplayChannel *display, int surface_id, const SpiceRec
surface = &display->surfaces[surface_id];
if (update) {
- red_update_area(display, area, surface_id);
+ display_channel_draw(display, area, surface_id);
}
canvas = surface->context.canvas;
@@ -1436,7 +1436,7 @@ static void validate_area(DisplayChannel *display, const SpiceRect *area, uint32
Renders drawables for updating the requested area, but only drawables that are older
than 'last' (exclusive).
*/
-static void red_update_area_till(DisplayChannel *display, const SpiceRect *area, int surface_id,
+static void display_channel_draw_till(DisplayChannel *display, const SpiceRect *area, int surface_id,
Drawable *last)
{
RedSurface *surface;
@@ -1503,10 +1503,10 @@ static void red_update_area_till(DisplayChannel *display, const SpiceRect *area,
container = now->tree_item.base.container;
current_remove_drawable(display, now);
container_cleanup(container);
- /* drawable_draw may call red_update_area for the surfaces 'now' depends on. Notice,
- that it is valid to call red_update_area in this case and not red_update_area_till:
+ /* drawable_draw may call display_channel_draw for the surfaces 'now' depends on. Notice,
+ that it is valid to call display_channel_draw in this case and not display_channel_draw_till:
It is impossible that there was newer item then 'last' in one of the surfaces
- that red_update_area is called for, Otherwise, 'now' would have already been rendered.
+ that display_channel_draw is called for, Otherwise, 'now' would have already been rendered.
See the call for red_handle_depends_on_target_surface in red_process_draw */
drawable_draw(display, now);
display_channel_drawable_unref(display, now);
@@ -1514,7 +1514,7 @@ static void red_update_area_till(DisplayChannel *display, const SpiceRect *area,
validate_area(display, area, surface_id);
}
-static void red_update_area(DisplayChannel *display, const SpiceRect *area, int surface_id)
+static void display_channel_draw(DisplayChannel *display, const SpiceRect *area, int surface_id)
{
RedSurface *surface;
Ring *ring;
@@ -1687,7 +1687,7 @@ static int red_process_commands(RedWorker *worker, uint32_t max_pipe_size, int *
spice_warning("Invalid surface in QXL_CMD_UPDATE");
break;
}
- red_update_area(worker->display_channel, &update.area, update.surface_id);
+ display_channel_draw(worker->display_channel, &update.area, update.surface_id);
worker->qxl->st->qif->notify_update(worker->qxl, update.update_id);
release_info_ext.group_id = ext_cmd.group_id;
release_info_ext.info = update.release_info;
@@ -2337,7 +2337,7 @@ static void red_add_lossless_drawable_dependencies(RedChannelClient *rcc,
} else {
sync_rendered = FALSE;
for (i = 0; i < num_deps; i++) {
- red_update_area_till(display, deps_areas[i],
+ display_channel_draw_till(display, deps_areas[i],
deps_surfaces_ids[i], item);
}
}
@@ -5370,7 +5370,7 @@ void display_channel_update(DisplayChannel *display,
spice_return_if_fail(validate_surface(display, surface_id));
red_get_rect_ptr(&rect, area);
- red_update_area(display, &rect, surface_id);
+ display_channel_draw(display, &rect, surface_id);
surface = &display->surfaces[surface_id];
if (!*qxl_dirty_rects) {